@@ -45,8 +45,6 @@ def default_60xvar(name, args, pos, info):
     """
     if len(args) != 1:
         raise generic.ScriptError("'%s'() requires one argument, encountered %d" % (name, len(args)), pos)
-    if isinstance(args[0], expression.ConstantNumeric):
-        generic.check_range(args[0].value, 0, 255, "Argument of '%s'" % name, args[0].pos)
     return (args[0], [])
 
 def signextend(var, info):
@@ -136,8 +134,9 @@ varact2vars_vehicles = {
 varact2vars_trains = {
     #0x4786 / 0x10000 is an approximation of 3.5790976, the conversion factor
     #for train speed
-    'max_speed'     : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x4786, 0x10000)},
-    'current_speed' : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x4786, 0x10000)},
+    'max_speed'           : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x4786, 0x10000)},
+    'current_speed'       : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x4786, 0x10000)},
+    'current_max_speed'   : {'var': 0x4C, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x4786, 0x10000)},
     'vehicle_is_in_depot' : {'var': 0xE2, 'start': 7, 'size': 1}
 }
 varact2vars_trains.update(varact2vars_vehicles)
@@ -145,8 +144,9 @@ varact2vars_trains.update(varact2vars_vehicles)
 varact2vars_roadvehs = {
     #0x23C3 / 0x10000 is an approximation of 7.1581952, the conversion factor
     #for road vehicle speed
-    'max_speed'     : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
-    'current_speed' : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'max_speed'           : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'current_speed'       : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'current_max_speed'   : {'var': 0x4C, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
     'vehicle_is_in_depot' : {'var': 0xE2, 'start': 0, 'size': 8, 'function': lambda var, info: expression.BinOp(nmlop.CMP_EQ, var, expression.ConstantNumeric(0xFE, var.pos))},
 }
 varact2vars_roadvehs.update(varact2vars_vehicles)
@@ -154,23 +154,41 @@ varact2vars_roadvehs.update(varact2vars_vehicles)
 varact2vars_ships = {
     #0x23C3 / 0x10000 is an approximation of 7.1581952, the conversion factor
     #for ship speed
-    'max_speed'     : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
-    'current_speed' : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'max_speed'           : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'current_speed'       : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
+    'current_max_speed'   : {'var': 0x4C, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x23C3, 0x10000)},
     'vehicle_is_in_depot' : {'var': 0xE2, 'start': 7, 'size': 1}
 }
 varact2vars_ships.update(varact2vars_vehicles)
 
 varact2vars_aircraft = {
     #0x3939 / 0x1000 is an approximation of 0.279617, the conversion factor
+    #Note that the denominator has one less zero here!
     #for aircraft speed
-    'max_speed'     : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x3939, 0x1000)},
-    'current_speed' : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x3939, 0x1000)},
-    #No such thing as identical to vehicle_is_in_depot exists for aircraft
+    'max_speed'           : {'var': 0x98, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x3939, 0x1000)},
+    'current_speed'       : {'var': 0xB4, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x3939, 0x1000)},
+    'current_max_speed'   : {'var': 0x4C, 'start': 0, 'size': 16, 'function': lambda var, info: muldiv(var, 0x3939, 0x1000)},
+    'vehicle_is_in_depot' : {'var': 0xE6, 'start': 0, 'size': 8, 'function': lambda var, info: expression.BinOp(nmlop.CMP_EQ, var, expression.ConstantNumeric(0, var.pos))},
 }
 varact2vars_aircraft.update(varact2vars_vehicles)
 
+def signed_byte_parameter(name, args, pos, info):
+    # Convert to a signed byte by AND-ing with 0xFF
+    if len(args) != 1:
+        raise generic.ScriptError("%s() requires one argument, encountered %d" % (name, len(args)), pos)
+    if isinstance(args[0], expression.ConstantNumeric):
+    
+        generic.check_range(args[0].value, -128, 127, "parameter of %s()" % name, pos)
+    ret = expression.BinOp(nmlop.AND, args[0], expression.ConstantNumeric(0xFF, pos), pos).reduce()
+    return (ret, [])
+
 varact2vars60x_vehicles = {
-    'count_veh_id': {'var': 0x60, 'start': 0, 'size': 8},
+    'count_veh_id'        : {'var': 0x60, 'start':  0, 'size': 8},
+    'other_veh_curv_info' : {'var': 0x62, 'start':  0, 'size': 4, 'param_function':signed_byte_parameter, 'value_function':signextend},
+    'other_veh_is_hidden' : {'var': 0x62, 'start':  7, 'size': 1, 'param_function':signed_byte_parameter},
+    'other_veh_x_offset'  : {'var': 0x62, 'start':  8, 'size': 8, 'param_function':signed_byte_parameter, 'value_function':signextend},
+    'other_veh_y_offset'  : {'var': 0x62, 'start': 16, 'size': 8, 'param_function':signed_byte_parameter, 'value_function':signextend},
+    'other_veh_z_offset'  : {'var': 0x62, 'start': 24, 'size': 8, 'param_function':signed_byte_parameter, 'value_function':signextend},
 }
 
 varact2vars_canals = {
@@ -238,6 +256,8 @@ varact2vars_industries = {
     'random_bits' : {'var': 0x5F, 'start': 8, 'size': 16},
     'produced_cargo_waiting_1' : {'var': 0x8A, 'start': 0, 'size': 16},
     'produced_cargo_waiting_2' : {'var': 0x8C, 'start': 0, 'size': 16},
+    'production_rate_1' : {'var': 0x8E, 'start': 0, 'size': 8},
+    'production_rate_2' : {'var': 0x8F, 'start': 0, 'size': 8},
     'production_level' : {'var': 0x93, 'start': 0, 'size': 8},
     'produced_this_month_1' : {'var': 0x94, 'start': 0, 'size': 16},
     'produced_this_month_2' : {'var': 0x96, 'start': 0, 'size': 16},
@@ -259,8 +279,6 @@ varact2vars_industries = {
 def industry_count(name, args, pos, info):
     if len(args) < 1 or len(args) > 2:
         raise generic.ScriptError("'%s'() requires between 1 and 2 argument(s), encountered %d" % (name, len(args)), pos)
-    if isinstance(args[0], expression.ConstantNumeric):
-        generic.check_range(args[0].value, 0, 255, "First argument of '%s'" % name, args[0].pos)
 
     grfid = expression.ConstantNumeric(0xFFFFFFFF) if len(args) == 1 else args[1]
     extra_params = [(0x100, grfid)]
@@ -271,8 +289,6 @@ def industry_count(name, args, pos, info):
 def industry_layout_count(name, args, pos, info):
     if len(args) < 2 or len(args) > 3:
         raise generic.ScriptError("'%s'() requires between 2 and 3 argument(s), encountered %d" % (name, len(args)), pos)
-    if isinstance(args[0], expression.ConstantNumeric):
-        generic.check_range(args[0].value, 0, 255, "First argument of '%s'" % name, args[0].pos)
 
     grfid = expression.ConstantNumeric(0xFFFFFFFF) if len(args) == 2 else args[2]
 
@@ -284,14 +300,12 @@ def industry_layout_count(name, args, pos, info):
 def industry_town_count(name, args, pos, info):
     if len(args) < 1 or len(args) > 2:
         raise generic.ScriptError("'%s'() requires between 1 and 2 argument(s), encountered %d" % (name, len(args)), pos)
-    if isinstance(args[0], expression.ConstantNumeric):
-        generic.check_range(args[0].value, 0, 255, "First argument of '%s'" % name, args[0].pos)
 
     grfid = expression.ConstantNumeric(0xFFFFFFFF) if len(args) == 1 else args[1]
 
     extra_params = []
     extra_params.append( (0x100, grfid) )
-    extra_params.append( (0x101, expression.ConstantNumeric(0x0100).reduce()) )
+    extra_params.append( (0x101, expression.ConstantNumeric(0x0100)) )
     return (args[0], extra_params)
 
 varact2vars60x_industries = {
@@ -361,11 +375,12 @@ varact2vars60x_objects = {
 }
 
 varact2vars_railtype = {
-    'terrain_type' : {'var': 0x40, 'start': 0, 'size': 8},
-    'enhanced_tunnels': {'var': 0x41, 'start': 0, 'size': 8},
-    'level_crossing_status': {'var': 0x42, 'start': 0, 'size': 8},
-    'build_date': {'var': 0x43, 'start': 0, 'size': 32},
-    'random_bits' : {'var': 0x5F, 'start': 8, 'size': 2},
+    'terrain_type'          : {'var': 0x40, 'start': 0, 'size':  8},
+    'enhanced_tunnels'      : {'var': 0x41, 'start': 0, 'size':  8},
+    'level_crossing_status' : {'var': 0x42, 'start': 0, 'size':  8},
+    'build_date'            : {'var': 0x43, 'start': 0, 'size': 32},
+    'town_zone'             : {'var': 0x44, 'start': 0, 'size':  8},
+    'random_bits'           : {'var': 0x5F, 'start': 8, 'size':  2},
 }
 
 varact2vars_airporttiles = {
