@@ -146,23 +146,28 @@ constant_numbers = {
     'TRAIN_FLAG_MU'   : 2,
     'TRAIN_FLAG_FLIP' : 3,
     'TRAIN_FLAG_AUTOREFIT': 4,
+    'TRAIN_FLAG_NO_BREAKDOWN_SMOKE': 6,
 
     #roadveh misc flags
     'ROADVEH_FLAG_TRAM' : 0,
     'ROADVEH_FLAG_2CC'  : 1,
     'ROADVEH_FLAG_AUTOREFIT': 4,
+    'ROADVEH_FLAG_NO_BREAKDOWN_SMOKE': 6,
 
     #ship misc flags
     'SHIP_FLAG_2CC'  : 1,
     'SHIP_FLAG_AUTOREFIT': 4,
+    'SHIP_FLAG_NO_BREAKDOWN_SMOKE': 6,
 
     #aircrafts misc flags
     'AIRCRAFT_FLAG_2CC'  : 1,
     'AIRCRAFT_FLAG_AUTOREFIT': 4,
+    'AIRCRAFT_FLAG_NO_BREAKDOWN_SMOKE': 6,
 
     #for those, who can't tell the difference between a train and an aircraft:
     'VEHICLE_FLAG_2CC' : 1,
     'VEHICLE_FLAG_AUTOREFIT': 4,
+    'VEHICLE_FLAG_NO_BREAKDOWN_SMOKE': 6,
 
     #Graphic flags for waterfeatures
     'WATERFEATURE_ALTERNATIVE_SPRITES' : 0,
@@ -196,6 +201,7 @@ constant_numbers = {
     'CB_RESULT_COLOUR_MAPPING_ADD_CC'      : 0x4000,
 
     'CB_RESULT_AUTOREFIT'                  : 0x4000,
+    'CB_RESULT_REFIT_COST_MASK'            : 0x3FFF,
 
     'CB_RESULT_NO_SOUND'                   : 0x7EFF, # Never a valid sound id
 
